@@ -50,7 +50,6 @@
 GWEN_INHERIT(GWEN_CRYPT_TOKEN, GWEN_CRYPT_TOKEN_OHBCI)
 
 
-
 GWEN_PLUGIN *ct_ohbci_factory(GWEN_PLUGIN_MANAGER *pm,
 			      const char *modName,
 			      const char *fileName) {
@@ -1031,7 +1030,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
 
       /* set key */
       if (GWEN_Crypt_Token_GetModes(ct) & GWEN_CRYPT_TOKEN_MODE_DIRECT_SIGN){
-        DBG_ERROR(0, "Adding mode \"direct sign\" to key");
+        DBG_INFO(GWEN_LOGDOMAIN, "Adding mode \"direct sign\" to key");
 	GWEN_Crypt_KeyRsa_AddFlags(key, GWEN_CRYPT_KEYRSA_FLAGS_DIRECTSIGN);
       }
       GWEN_CTF_Context_SetLocalSignKey(fct, key);
@@ -1349,7 +1348,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
       GWEN_CTF_Context_SetLocalAuthKeyInfo(fct, ki);
       /* set key */
       if (GWEN_Crypt_Token_GetModes(ct) & GWEN_CRYPT_TOKEN_MODE_DIRECT_SIGN){
-        DBG_ERROR(0, "Adding mode \"direct sign\" to key");
+        DBG_INFO(GWEN_LOGDOMAIN, "Adding mode \"direct sign\" to key");
 	GWEN_Crypt_KeyRsa_AddFlags(key, GWEN_CRYPT_KEYRSA_FLAGS_DIRECTSIGN);
       }
       GWEN_CTF_Context_SetLocalAuthKey(fct, key);
@@ -1428,7 +1427,7 @@ int GWEN_Crypt_TokenOHBCI__Decode(GWEN_CRYPT_TOKEN *ct, GWEN_BUFFER *dbuf) {
       GWEN_CTF_Context_SetRemoteAuthKeyInfo(fct, ki);
       /* set key */
       if (GWEN_Crypt_Token_GetModes(ct) & GWEN_CRYPT_TOKEN_MODE_DIRECT_SIGN){
-        DBG_ERROR(0, "Adding mode \"direct sign\" to key");
+        DBG_INFO(GWEN_LOGDOMAIN, "Adding mode \"direct sign\" to key");
 	GWEN_Crypt_KeyRsa_AddFlags(key, GWEN_CRYPT_KEYRSA_FLAGS_DIRECTSIGN);
       }
       GWEN_CTF_Context_SetRemoteAuthKey(fct, key);
