@@ -117,7 +117,7 @@ int GWEN_Crypt_KeyRsa_Sign(GWEN_CRYPT_KEY *k,
     gcry_mpi_sub(mpi_sigout2, mpi_n, mpi_sigout1);
 
     if (gcry_mpi_cmp(mpi_sigout2, mpi_sigout1)<0) {
-      DBG_ERROR(GWEN_LOGDOMAIN, "Choosing 2nd variant");
+      DBG_DEBUG(GWEN_LOGDOMAIN, "Choosing 2nd variant");
       gcry_mpi_set(mpi_sigout1, mpi_sigout2);
     }
   }
@@ -209,7 +209,7 @@ int GWEN_Crypt_KeyRsa_Verify(GWEN_CRYPT_KEY *k,
 
     mpi_sigin2=gcry_mpi_new(GWEN_Crypt_Key_GetKeySize(k));
 
-    DBG_ERROR(GWEN_LOGDOMAIN, "Trying 2nd variant");
+    DBG_DEBUG(GWEN_LOGDOMAIN, "Trying 2nd variant");
     gcry_mpi_sub(mpi_sigin2, mpi_n, mpi_sigin1);
     gcry_mpi_powm(mpi_sigout, mpi_sigin2, mpi_e, mpi_n);
     if (gcry_mpi_cmp(mpi_sigout, mpi_in)) {
@@ -395,10 +395,12 @@ int GWEN_Crypt_KeyRsa__ReadMpi(GWEN_DB_NODE *db,
     return GWEN_ERROR_GENERIC;
   }
   if (nscanned<1) {
-    DBG_INFO(GWEN_LOGDOMAIN, "Empty %s", dbName);
+    DBG_INFO(GWEN_LOGDOMAIN, "Empty %s (%d)", dbName, (int)nscanned);
+#if 0
     if (mpi)
       gcry_mpi_release(mpi);
     return GWEN_ERROR_BAD_DATA;
+#endif
   }
   err=gcry_ac_data_set(ds, GCRY_AC_FLAG_COPY, (char*)dsName, mpi);
   if (err) {
@@ -986,6 +988,12 @@ int GWEN_Crypt_KeyRsa_GetExponent(const GWEN_CRYPT_KEY *k, uint8_t *buffer, uint
 
 
 
+int GWEN_Crypt_KeyRsa_GetSecretExponent(const GWEN_CRYPT_KEY *k, uint8_t *buffer, uint32_t *pBufLen) {
+  return GWEN_Crypt_KeyRsa__GetNamedElement(k, "d", buffer, pBufLen);
+}
+
+
+
 GWEN_CRYPT_KEY *GWEN_Crypt_KeyRsa_fromModExp(unsigned int nbytes,
 					     const uint8_t *pModulus,
 					     uint32_t lModulus,
