@@ -940,28 +940,29 @@ int GWEN_Gui_CGui_GetPassword(GWEN_GUI *gui,
   
     buf=GWEN_Buffer_new(0, 256, 0, 1);
     GWEN_Text_EscapeToBufferTolerant(token, buf);
-  
-    s=GWEN_DB_GetCharValue(cgui->dbPasswords,
-			   GWEN_Buffer_GetStart(buf),
-			   0, NULL);
-    if (s) {
-      int i;
-  
-      i=strlen(s);
-      if (i>=minLen && i<=maxLen) {
-	memmove(buffer, s, i+1);
-	GWEN_Buffer_free(buf);
-	return 0;
+
+    if (!(flags & GWEN_GUI_INPUT_FLAGS_CONFIRM)) {
+      s=GWEN_DB_GetCharValue(cgui->dbPasswords,
+			     GWEN_Buffer_GetStart(buf),
+			     0, NULL);
+      if (s) {
+	int i;
+
+	i=strlen(s);
+	if (i>=minLen && i<=maxLen) {
+	  memmove(buffer, s, i+1);
+	  GWEN_Buffer_free(buf);
+	  return 0;
+	}
       }
     }
-    else {
-      if (cgui->nonInteractive) {
-	DBG_ERROR(GWEN_LOGDOMAIN,
-		  "Password for [%s] missing in noninteractive mode, "
-		  "aborting", token);
-	GWEN_Buffer_free(buf);
-        return GWEN_ERROR_USER_ABORTED;
-      }
+
+    if (cgui->nonInteractive) {
+      DBG_ERROR(GWEN_LOGDOMAIN,
+		"Password for [%s] missing in noninteractive mode, "
+		"aborting", token);
+      GWEN_Buffer_free(buf);
+      return GWEN_ERROR_USER_ABORTED;
     }
 
     for (;;) {
@@ -1045,6 +1046,18 @@ void GWEN_Gui_CGui_SetPasswordDb(GWEN_GUI *gui,
 
 
 
+GWEN_DB_NODE *GWEN_Gui_CGui_GetPasswordDb(const GWEN_GUI *gui) {
+  GWEN_GUI_CGUI *cgui;
+
+  assert(gui);
+  cgui=GWEN_INHERIT_GETDATA(GWEN_GUI, GWEN_GUI_CGUI, gui);
+  assert(cgui);
+
+  return cgui->dbPasswords;
+}
+
+
+
 void GWEN_Gui_CGui_SetCertDb(GWEN_GUI *gui, GWEN_DB_NODE *dbCerts) {
   GWEN_GUI_CGUI *cgui;
 
@@ -1058,5 +1071,14 @@ void GWEN_Gui_CGui_SetCertDb(GWEN_GUI *gui, GWEN_DB_NODE *dbCerts) {
 
 
 
+GWEN_DB_NODE *GWEN_Gui_CGui_GetCertDb(const GWEN_GUI *gui) {
+  GWEN_GUI_CGUI *cgui;
+
+  assert(gui);
+  cgui=GWEN_INHERIT_GETDATA(GWEN_GUI, GWEN_GUI_CGUI, gui);
+  assert(cgui);
+
+  return cgui->dbCerts;
+}
 
 
