@@ -22,6 +22,7 @@
 #include <gwenhywfar/misc2.h>
 #include <gwenhywfar/inherit.h>
 #include <gwenhywfar/ct.h>
+#include <gwenhywfar/ctplugin.h>
 
 #include <string.h>
 #include <errno.h>
@@ -31,6 +32,9 @@
 #include "src/base/i18n_l.h"
 
 
+GWEN_CRYPT_TOKEN *getCryptToken(const char *ttype, const char *tname);
+
+
 int createToken(GWEN_DB_NODE *dbArgs, int argc, char **argv);
 
 int showUser(GWEN_DB_NODE *dbArgs, int argc, char **argv);
@@ -43,6 +47,8 @@ int updateToken(GWEN_DB_NODE *dbArgs, int argc, char **argv);
 
 int setSignSeq(GWEN_DB_NODE *dbArgs, int argc, char **argv);
 
+int changePin(GWEN_DB_NODE *dbArgs, int argc, char **argv);
+
 
 #endif /* GCTTOOL_GLOBALS_H */
 
