@@ -43,6 +43,16 @@
 # include <openssl/des.h>
 #endif
 
+#ifdef WITH_STATIC_PLUGINS
+int GWEN_Plugins_Init();
+int AB_Plugins_Init();
+int LC_Plugins_Init();
+# ifdef ENABLE_EBICS_PLUGINS
+int EBC_Plugins_Init();
+# endif
+#endif
+
+
 
 
 #ifdef HAVE_OPENSSL
@@ -68,6 +78,44 @@ int getKeyDataFromTextOpenSSL(GWEN_GUI *gui,
 #endif
 
 
+GWEN_CRYPT_TOKEN *getCryptToken(const char *ttype,
+				const char *tname) {
+  GWEN_PLUGIN_MANAGER *pm;
+  GWEN_PLUGIN *pl;
+  GWEN_CRYPT_TOKEN *ct;
+
+  /* get crypt token */
+  pm=GWEN_PluginManager_FindPluginManager("ct");
+  if (pm==0) {
+    DBG_ERROR(0, "Plugin manager not found");
+    return NULL;
+  }
+
+  pl=GWEN_PluginManager_GetPlugin(pm, ttype);
+  if (pl==0) {
+    DBG_ERROR(0, "Plugin not found");
+
+    fprintf(stderr,
+	    I18N("The plugin could not be found.\n"
+		 "Please make sure that you have the following "
+		 "packages installed (at least on Debian/Ubuntu):\n"
+		 "- libchipcard-plugins-libgwenhywfar (for chipcards)\n"
+                 "- libaqbanking-plugins-libgwenhywfar\n"));
+    return NULL;
+  }
+  DBG_INFO(0, "Plugin found");
+
+  ct=GWEN_Crypt_Token_Plugin_CreateToken(pl, tname);
+  if (ct==0) {
+    DBG_ERROR(0, "Could not create crypt token");
+    return NULL;
+  }
+
+  return ct;
+}
+
+
+
 int main(int argc, char **argv) {
   GWEN_DB_NODE *db;
   const char *cmd;
@@ -198,6 +246,32 @@ int main(int argc, char **argv) {
     argv+=rv-1;
   }
 
+#ifdef WITH_STATIC_PLUGINS
+  DBG_DEBUG(GWEN_LOGDOMAIN, "Initialising static plugins");
+  rv=GWEN_Plugins_Init();
+  if (rv<0) {
+    fprintf(stderr, "ERROR: Unable to init GWEN plugins (%d).\n", rv);
+    return 1;
+  }
+  rv=LC_Plugins_Init();
+  if (rv<0) {
+    fprintf(stderr, "ERROR: Unable to init Libchipcard plugins (%d).\n", rv);
+    return 1;
+  }
+  rv=AB_Plugins_Init();
+  if (rv<0) {
+    fprintf(stderr, "ERROR: Unable to init AqBanking plugins (%d).\n", rv);
+    return 1;
+  }
+#ifdef ENABLE_EBICS_PLUGINS
+  rv=EBC_Plugins_Init();
+  if (rv<0) {
+    fprintf(stderr, "ERROR: Unable to init AqEBICS plugins (%d).\n", rv);
+    return 1;
+  }
+#endif
+#endif
+
   cmd=GWEN_DB_GetCharValue(db, "params", 0, 0);
   if (!cmd) {
     fprintf(stderr, "ERROR: Command needed.\n");
@@ -222,6 +296,9 @@ int main(int argc, char **argv) {
   else if (strcasecmp(cmd, "setsignseq")==0) {
     rv=setSignSeq(db, argc, argv);
   }
+  else if (strcasecmp(cmd, "changepin")==0) {
+    rv=changePin(db, argc, argv);
+  }
   else {
     fprintf(stderr, "ERROR: Unknown command \"%s\".\n", cmd);
     rv=1;
